var documenterSearchIndex = {"docs":
[{"location":"index.html#Home-1","page":"Home","title":"NOMAD.jl documentation","text":"","category":"section"},{"location":"index.html#","page":"Home","title":"Home","text":"This package provides a Julia interface for NOMAD, which is a C++ implementation of the Mesh Adaptive Direct Search algorithm (MADS), designed for difficult blackbox optimization problems. These problems occur when the functions defining the objective and constraints are the result of costly computer simulations.","category":"page"},{"location":"index.html#Type-of-problems-treated-1","page":"Home","title":"Type of problems treated","text":"","category":"section"},{"location":"index.html#","page":"Home","title":"Home","text":"NOMAD allows to deal with optimization problems of the form :","category":"page"},{"location":"index.html#","page":"Home","title":"Home","text":"beginalign*\nmin quad  f(x) \n c_i(x) leq 0 quad i in I \n ell leq x leq u\nendalign*","category":"page"},{"location":"index.html#","page":"Home","title":"Home","text":"where fmathbbR^nrightarrowmathbbR, cmathbbR^nrightarrowmathbbR^m, I = 12dotsm, and ell_j u_j in mathbbRcuppminfty for i = 1dotsm.","category":"page"},{"location":"index.html#","page":"Home","title":"Home","text":"The functions f and c_i are typically blackbox functions whose evaluations require computer simulation.","category":"page"},{"location":"index.html#Quick-start-1","page":"Home","title":"Quick start","text":"","category":"section"},{"location":"index.html#","page":"Home","title":"Home","text":"You first need to declare a function eval(x::Vector{Float64}) that returns a boolean and a Vector{Float64} that contains the objective function and constraints evaluated for x.","category":"page"},{"location":"index.html#","page":"Home","title":"Home","text":"function eval(x)\n    f=x[1]^2+x[2]^2\n    c=1-x[1]\n    count_eval=true\n    bb_outputs = [f,c]\n    return (count_eval,bb_outputs)\nend","category":"page"},{"location":"index.html#","page":"Home","title":"Home","text":"The boolean count_eval defines whether the evaluation needs to be taken into account by NOMAD. Here, it is always equal to true so every evaluation will be considered.","category":"page"},{"location":"index.html#","page":"Home","title":"Home","text":"Then create an object of type parameters that will contain options for the optimization. You need to define at least the dimension of the problem, the initial point x0 and the types of the outputs contained in bb_outputs.","category":"page"},{"location":"index.html#","page":"Home","title":"Home","text":"param = parameters()\nparam.dimension = 2\nparam.output_types = [\"OBJ\",\"EB\"]\nparam.x0 = [3,3]","category":"page"},{"location":"index.html#","page":"Home","title":"Home","text":"Here, first element of bb_outputs is the objective function (f), second is a constraint treated with the Extreme Barrier method (c).","category":"page"},{"location":"index.html#","page":"Home","title":"Home","text":"Now call the function runopt with these arguments to launch a NOMAD optimization process.","category":"page"},{"location":"index.html#","page":"Home","title":"Home","text":"result = runopt(eval,param)","category":"page"},{"location":"index.html#","page":"Home","title":"Home","text":"The object of type results returned by runopt contains information about the run.","category":"page"},{"location":"nomadParameters.html#Parameters-setting-1","page":"Parameters","title":"Parameters setting","text":"","category":"section"},{"location":"nomadParameters.html#","page":"Parameters","title":"Parameters","text":"The settings of a NOMAD optimization process must be entered in an object of the type described below.","category":"page"},{"location":"nomadParameters.html#","page":"Parameters","title":"Parameters","text":"nomadParameters","category":"page"},{"location":"nomadParameters.html#NOMAD.nomadParameters","page":"Parameters","title":"NOMAD.nomadParameters","text":"nomadParameters\n\nmutable struct containing the options of the optimization process.\n\nThe attributes of this Julia type correspond to those of the NOMAD class NOMAD::Parameters. Hence, to get more information about setting nomadParameters in NOMAD.jl, you can refer to the NOMAD documentation.\n\nConstructors :\n\nClassic constructor :\np1 = nomadParameters(x0::Vector{Number},output_types::Vector{String})\nCopy constructor :\np1 = nomadParameters(p2)\n\nAttributes :\n\nx0::Vector{Number} :\n\nInitialization point for NOMAD. Needs to be of dimension n<=1000 No default value, needs to be set.\n\noutput_types::Vector{String} :\n\nA vector containing String objects that define the types of outputs returned by eval (the order is important) :\n\nString Output type\n\"OBJ\" objective value to be minimized\n\"PB\" or \"CSTR\" progressive barrier constraint\n\"EB\" extreme barrier constraint\n\"F\" filter approach constraint\n\"PEB\" hybrid constraint EB/PB\n\"STAT_AVG\" Average of this value will be computed for all blackbox calls (must be unique)\n\"STAT_SUM\" Sum of this value will be computed for all blackbox calls (must be unique)\n\"NOTHING\" or \"-\" The output is ignored\n\nPlease note that F constraints are not compatible with CSTR, PB or PEB. However, EB can be combined with F, CSTR, PB or PEB. No default value, needs to be set.\n\nlower_bound::Vector{Number} :\n\nLower bound for each coordinate of the state. If empty, no bound is taken into account. [] by default.\n\nupper_bound::Vector{Number} :\n\nUpper bound for each coordinate of the state. If empty, no bound is taken into account. [] by default.\n\ndisplay_all_eval::Bool :\n\nIf false, only evaluations that allow to improve the current state are displayed. false by default.\n\ndisplay_stats::String :\n\nString defining the way outputs are displayed (it should not contain any quotes). Here are examples of keywords that can be used :\n\nKeyword Display\nbbe black box evaluations\nobj objective function value\nsol solution\nbbo black box outputs\nmesh_index mesh index parameter\nmesh_size mesh size parameter\ncons_h Infeasibility\npoll_size Poll size parameter\nsgte Number of surrogate evaluations\nstat_avg AVG statistic defined in output types\nstat_sum SUM statistic defined in output types\ntime Wall-clock time\n\n\"bbe ( sol ) obj\" by default.\n\ndisplay_degree::Int :\n\nInteger between 0 and 3 that sets the level of display. 2 by default.\n\nmax_bb_eval::Int :\n\nMaximum of calls to eval allowed. if equal to zero, no maximum is taken into account. 0 by default.\n\nmax_time::Int :\n\nmaximum wall-clock time (in seconds). if equal to zero, no maximum is taken into account. 0 by default.\n\noutput_types::Vector{String} :\n\nA vector containing String objects that define the types of inputs to be given to eval (the order is important) :\n\nString Input type\n\"R\" Real/Continuous\n\"B\" Binary\n\"I\" Integer\n\nall R by default.\n\n\n\n\n\n","category":"type"},{"location":"run_nomad.html#Run-the-optimization-1","page":"Run Optimization","title":"Run the optimization","text":"","category":"section"},{"location":"run_nomad.html#","page":"Run Optimization","title":"Run Optimization","text":"A NOMAD optimization process can be run by using the runopt method described below.","category":"page"},{"location":"run_nomad.html#","page":"Run Optimization","title":"Run Optimization","text":"nomad(eval::Function,param::nomadParameters)","category":"page"},{"location":"run_nomad.html#NOMAD.nomad-Tuple{Function,nomadParameters}","page":"Run Optimization","title":"NOMAD.nomad","text":"nomad(eval::Function,param::nomadParameters)\n\n-> Run NOMAD with settings defined by param and an optimization problem defined by eval(x).\n\n-> Display stats from NOMAD in the REPL.\n\n-> return an object of type nomadResults that contains info about the run.\n\nArguments :\n\neval::Function\n\na function of the form : \t\t@test param.lowerbound<xi<param.upperbound\n\n(count_eval,bb_outputs)=eval(x::Vector{Float64})\n\nbb_outputs being a vector{Float64} containing the values of objective function and constraints for a given input vector x. NOMAD will seak for minimizing the objective function and keeping constraints inferior to 0. count_eval is a Bool equal to true if the evaluation has to be taken into account by NOMAD.\n\nparam::nomadParameters\n\nAn object of type Parameters of which the attributes are the settings of the optimization process (dimension, output types, display options, bounds, etc.).\n\nExample :\n\nusing NOMAD\n\nfunction eval(x)\n    f=x[1]^2+x[2]^2\n    c=1-x[1]\n    count_eval=true\n\tbb_outputs = [f,c]\n    return (count_eval,bb_outputs)\nend\n\nparam = nomadParameters()\nparam.dimension = 2\nparam.output_types = [\"OBJ\",\"EB\"] #=first element of bb_outputs is the\n\tobjective function, second is a constraint treated with the Extreme\n\tBarrier method=#\nparam.x0 = [3,3] #Initial state for the optimization process\n\nresult = nomad(eval,param)\n\n\n\n\n\n","category":"method"},{"location":"nomadResults.html#Results-1","page":"Results","title":"Results","text":"","category":"section"},{"location":"nomadResults.html#","page":"Results","title":"Results","text":"Main results from a NOMAD optimization process are stored in an object of the type described below.","category":"page"},{"location":"nomadResults.html#","page":"Results","title":"Results","text":"nomadResults","category":"page"},{"location":"nomadResults.html#NOMAD.nomadResults","page":"Results","title":"NOMAD.nomadResults","text":"nomadResults\n\nmutable struct containing info about a NOMAD run, returned by the method runopt(eval,param).\n\nTo display the info contained in a object result, use :\n\ndisp(result)\n\nAttributes :\n\nbest_feasible::Vector{Float64} :\n\nFeasible point found by NOMAD that best minimizes the objective function.\n\nbbo_best_feasible::Vector{Float64} :\n\nOutputs of eval(x) for the best feasible point.\n\nbest_infeasible::Vector{Float64} :\n\nInfeasible point found by NOMAD that best minimizes the objective function.\n\nbbo_best_infeasible::Vector{Float64} :\n\noutputs of eval(x) for the best infeasible point.\n\nbb_eval::Int64 :\n\nNumber of eval(x) evaluations\n\ninter_states::Matrix{Float64} :\n\nList of intermediate states evaluated during the optimization process. Lines correspond to successive states that are browsed and each column correspond to a dimension.\n\ninter_bbo::Vector{Float64} :\n\nList of black box outputs corresponding to intermediate states evaluated during the optimization process. Lines correspond to successive states that are browsed and each column correspond to  an output (same order as defined in nomadParameters.output_types).\n\ninter_bbo::Vector{Int64} :\n\nList of black box evaluations numbers required to reach each of the states available in inter_states.\n\n\n\n\n\n","category":"type"}]
}
